<?php
/**
 * Created by PhpStorm.
 * User: jderosa
 * Date: 31/10/19
 * Time: 12.23
 */

namespace FiloBlu\Rma\Plugin\Block\Form\Renderer;
use FiloBlu\Rma\Api\Model\Config\Reader;
use FiloBlu\Rma\Helper\InstallHelper;
use FiloBlu\Rma\Helper\SerializerHelper;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Store\Model\StoreManagerInterface;

class Select
{
    /**
     * @var Reader
     */
    protected $reader;

    /**
     * @var SerializerHelper
     */
    protected $serializer;

    /**
     * @var ScopeConfigInterface
     */
    protected $scopeConfig;

    /**
     * @var StoreManagerInterface
     */
    protected $storeManager;


    const CHANGE_SIZE_ENABLE ='filoblu_disablerma_section/rma_group/rma_change_size';


    /**
     * Select constructor.
     * @param Reader $reader
     * @param SerializerHelper $serializer
     * @param ScopeConfigInterface $scopeConfig
     * @param StoreManagerInterface $storeManager
     */
    public function __construct(Reader $reader,
                                SerializerHelper $serializer,
                                ScopeConfigInterface $scopeConfig,
                                StoreManagerInterface $storeManager)
    {
        $this->reader = $reader;
        $this->serializer = $serializer;
        $this->scopeConfig = $scopeConfig;
        $this->storeManager = $storeManager;
    }

    /**
     * @param \Magento\Rma\Block\Form\Renderer\Select $subject
     * @param $result
     * @return mixed
     */
    public function afterGetOptions(\Magento\Rma\Block\Form\Renderer\Select $subject, $result)
    {

        $attribute_code = $subject->getAttributeObject()->getAttributeCode() ;

        $all_options = $result;

        if ($attribute_code == 'reason') {

            $standard_reasons_config = $this->reader->read();
            $configData = $this->scopeConfig->getValue('sales/rma_reason/reason') ?? '';

            if ($configData != '') {
                $rma_reason_options = array();
                $mapping = $this->serializer->unserialize($configData);
                if (count($mapping) > 0) {


                    foreach ($all_options as $option) {
                        $_brand_reason_option_id = $option['value'];
                        $_standard_reason_option_id = null;
                        foreach ($mapping as $map) {
                            if ($map['brand_reason'] == $_brand_reason_option_id) {
                                $_standard_reason_option_id = $map['standard_reason'];
                                break;
                            }
                        }

                        $_visible_on_front = 0;
                        if ($_standard_reason_option_id) {
                            foreach ($standard_reasons_config as $reason) {
                                if ($reason['id'] == $_standard_reason_option_id) {
                                    $_visible_on_front = $reason['visible_on_front'];
                                }
                            }
                        }

                        // se le motivazioni non sono mappate a BE, a frontend non compaiono
                        if ($_visible_on_front) {
                            $rma_reason_options[] = $option;
                        }

                    }

                    // escludo dalla select di frontend tutte le motivazioni riservate al backend
                    // configurazioni in FiloBlu/Rma/etc/rma_reasons.xml
                    return $rma_reason_options;
                }
            }else{
                return $all_options;
            }
        }

        if ($attribute_code == 'resolution'){
            $emptyLabel = false;
            $empty = [] ;
            $empty [] =["value"=>"","label"=>" "];
            foreach ($all_options as $option){
                if($option['label'] == " " || $option['label']== ""){
                    $emptyLabel = true;
                }
            }
            if(!$emptyLabel){
                $all_options = array_merge($empty,$all_options);
            }
            if(!$this->changeSizeIsEnabled()){
                $allowed =[];
                foreach ($all_options as $option){
                    if($option['label'] != InstallHelper::REASON_CHANGE_SIZE_LABEL){
                        $allowed [] = $option;
                    }
                }
                $all_options = $allowed;
            }
        }


        return $all_options;
    }

    /**
     * @return mixed
     */
    public function changeSizeIsEnabled(){

        return $this->scopeConfig->getValue(self::CHANGE_SIZE_ENABLE);
    }

}